function [ct,U,U_u,U_0,V,S_0,S_00,S_u,S_u0]=GF_sw_cart(XX0,XX1,Rs,cdt)
% Green function in Schwarzschild Cartisian coordinates
% source XX0=(x0,y0,z0) -> field XX1=(x1,y1,z1)
% cdt: time step 
% Rs:  Schwarzschild radius
% ct:  time interval between XX0 and XX1
eps_theta=1e-7;
[Te,Xe0,Xe1]=cart_equator(XX0,XX1); % Convert to equatorial plane, Xe = Te * XX
X0=cart2sph_sw(Xe0,Rs); % Convert to spherical coordinates
if(abs(X0(2)-pi/2)>eps_theta)
    error('cart_equator error for X0!');
else
    X0(2)=pi/2;
end
X1=cart2sph_sw(Xe1,Rs);
if(abs(X1(2)-pi/2)>eps_theta)
    error('cart_equator error for X1!');
else
    X1(2)=pi/2;
end
if(X1(3)<X0(3))
    X1(3)=X1(3)+2*pi;
end
%
r=[X0(1),X1(1)];
R=[norm(XX0),norm(XX1)];
cdt=min(((R-Rs/4)./(R+Rs/4)).^2./(1-Rs./r))*cdt;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[ct,U,U_u,U_p,V,S_u,S_p,S_up,S_pp]=GF_sw_sph(X0(1),X0(3),X1(1),X1(3),Rs,cdt);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T0=dxs_dxc(X0,Rs); %  Convert matrix beteween  Cartisian and  spherical
T1=dxs_dxc(X1,Rs);
%
U=T1.'*U*T0;
U_u=dot_TT(dot_TT(dot_TT(U_u,1,T1,1),1,T0,1),1,T1,1);
U_p=dot_TT(dot_TT(dot_TT(U_p,1,T1,1),1,T0,1),1,T0,1);
V=T1.'*V*T0;
S_u=T1.'*S_u;
S_p=T0.'*S_p;
S_up=T1.'*S_up*T0;
S_pp=T0.'*S_pp*T0;
%
U=Te.'*U*Te;
U_u=dot_TT(dot_TT(dot_TT(U_u,1,Te,1),1,Te,1),1,Te,1);
U_p=dot_TT(dot_TT(dot_TT(U_p,1,Te,1),1,Te,1),1,Te,1);
V=Te.'*V*Te;
S_u=Te.'*S_u;
S_p=Te.'*S_p;
S_up=Te.'*S_up*Te;
S_pp=Te.'*S_pp*Te;
%
S_0=S_p(1);
C=Christoffel_sw_cart(XX0,Rs);
S_00=S_pp(1,1)+C(:,1,1).'*S_p;
S_u0=S_up(:,1);
U_0=U_p(:,:,1)+U*C(:,:,1);
end