function [E,ct0]=dipole_sw(Rs,Xp,Xn,X,A,BW,cdt,cT)
% Rs: Schwarzschild radius
% Xp: Coordinates of the positive charge
% Xn: Coordinates of the negtive charge
% X:  Coordinates of the field point (Cartisian coordinate)
% A:  amplitude
% BWbandwith(Hz)
% cdttime step
% cT total time interval
% E  Electric field at X
% ct0start time of E
c=299792458;
sgm=0.568/BW;
Xp=Xp(:);Xn=Xn(:);X=X(:);
L=Xp-Xn;
N=ceil(cT/cdt);
%
[Ep,ctp]=genE_sw(Rs,Xp,X,@(t) [c*q(t,A,sgm);0;0;0],@(t) [q1(t,A,sgm);0;0;0],cdt,N);
[En,ctn]=genE_sw(Rs,Xn,X,@(t) [-c*q(t,A,sgm);0;0;0],@(t) [-q1(t,A,sgm);0;0;0],cdt,N);
[Em,ctm]=genE_sw(Rs,(Xp+Xn)/2,X,@(t) [0;q1(t,A,sgm)*L],@(t) [0;q2(t,A,sgm)*L/c],cdt,N);
%
ct0=max([ctp,ctn,ctm]);
ct1=min([ctp,ctn,ctm])+(N-1)*cdt;
E=   interp1(ctp+(0:N-1)*cdt,Ep.',ct0:cdt:ct1).'...
    +interp1(ctn+(0:N-1)*cdt,En.',ct0:cdt:ct1).'...
    +interp1(ctm+(0:N-1)*cdt,Em.',ct0:cdt:ct1).';
end
%
function [E,ct0]=genE_sw(Rs,X0,X,JgV,J0gV,cdt,N)
E=zeros(3,N);
[ct0,U,U_u,U_0,V,S_0,S_00,S_u,S_u0]=GF_sw_cart(X0,X,Rs,cdt);
for i=1:N
    t=(i-1)*cdt/299792458;
    E(:,i)=dE(U,U_u,U_0,V,S_0,S_00,S_u,S_u0,JgV(t),J0gV(t));
end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function s=q(t,A,sgm)
s=-A*sgm*exp(0.5)*exp(-0.5*(t/sgm-4)^2);
end
%
function s=q1(t,A,sgm)
s=A*exp(0.5)*(t/sgm-4)*exp(-0.5*(t/sgm-4)^2);
end
%
function s=q2(t,A,sgm)
s=A*exp(0.5)*(1-(t/sgm-4)^2)*exp(-0.5*(t/sgm-4)^2)/sgm;
end